@@ -135,6 +135,7 @@ class Table:
         obj = data[0]
         column_names = self._column_name_getter(obj)
         column_values = self._column_value_getter(obj)
+        column_map = {}
 
         # Do not update columns or index if predefined
         add_columns = not bool(self._columns)
@@ -143,19 +144,26 @@ class Table:
         for idx, obj in enumerate(data):
             row = [None] * len(self._columns)
 
-            for column in column_names(obj):
+            for column_src in column_names(obj):
+                # Check if column has been added with different name
+                column_dst = column_map.get(column_src, column_src)
+
                 # Dictionaries and namedtuples can
                 # contain unknown columns
-                if column not in self._columns:
+                if column_dst not in self._columns:
                     if not add_columns:
                         continue
 
-                    self._add_column(column)
+                    # Store map of source column name to created name
+                    col = self._add_column(column_dst)
+                    column_dst = self._columns[col]
+                    column_map[column_src] = column_dst
+
                     while len(row) < len(self._columns):
                         row.append(None)
 
-                col = self.column_location(column)
-                row[col] = column_values(obj, column)
+                col = self.column_location(column_dst)
+                row[col] = column_values(obj, column_src)
 
             self._data.append(row)
 
@@ -810,6 +818,8 @@ class Table:
     def filter_by_column(self, column, condition):
         """Remove rows by evaluating `condition` for all `column`
         values. All rows where it evaluates to falsy are removed.
+
+        The filtering will be done in-place.
         """
         filtered = []
         for index in self.index:
@@ -1349,7 +1359,38 @@ class Tables:
         return groups
 
     def filter_table_by_column(self, table, column, operator, value):
-        """Return all rows where the column values match the given condition.
+        """Remove all rows where the column values don't match the
+        given condition.
+
+        Supported operators:
+
+        ============ ========================================
+        Operator     Description
+        ============ ========================================
+        >            Cell value is larger than
+        <            Cell value is smaller than
+        >=           Cell value is larger or equal than
+        <=           Cell value is smaller or equal than
+        ==           Cell value is equal to
+        !=           Cell value is not equal to
+        contains     Cell value contains given value
+        not contains Cell value does not contain given value
+        in           Cell value is in given value
+        not in       Cell value is not in given value
+        ============ ========================================
+
+        The filtering will be done in-place.
+
+        Examples:
+
+        .. code-block:: robotframework
+
+            # Only accept prices that are non-zero
+            Filter table by column    ${table}   price  !=  ${0}
+
+            # Remove uwnanted product types
+            @{types}=    Create list    Unknown    Removed
+            Filter table by column    ${table}   product_type  not in  ${types}
 
         :param table:       table to filter
         :param column:      column to filter with
@@ -1367,7 +1408,9 @@ class Tables:
             "==": lambda x: x is not None and x == value,
             "!=": lambda x: x is not None and x != value,
             "contains": lambda x: x is not None and value in x,
+            "not contains": lambda x: x is not None and value not in x,
             "in": lambda x: x in value,
+            "not in": lambda x: x not in value,
         }.get(operator)
 
         if not condition:
@@ -1380,6 +1423,8 @@ class Tables:
     def filter_empty_rows(self, table):
         """Remove all rows from the table which have only None values.
 
+        The filtering will be done in-place.
+
         :param table:   table to filter
         """
         self._requires_table(table)
@@ -1417,15 +1462,25 @@ class Tables:
         ]
 
     def read_table_from_csv(
-        self, path, header=None, columns=None, dialect=None, delimiters=None
+        self,
+        path,
+        header=None,
+        columns=None,
+        dialect=None,
+        delimiters=None,
+        column_unknown="Unknown",
+        encoding=None,
     ):
         """Read a CSV file as a table.
 
-        :param path:        path to CSV file
-        :param header:      CSV file includes header
-        :param columns:     names of columns in resulting table
-        :param dialect:     format of CSV file
-        :param delimiters:  string of possible delimiters
+        :param path:            path to CSV file
+        :param header:          CSV file includes header
+        :param columns:         names of columns in resulting table
+        :param dialect:         format of CSV file
+        :param delimiters:      string of possible delimiters
+        :param column_unknown:  column name for unknown fields
+        :param encoding:        text encoding for input file,
+                                uses system encoding by default
 
         By default attempts to deduce the CSV format and headers
         from a sample of the input file. If it's unable to determine
@@ -1439,9 +1494,25 @@ class Tables:
         The ``columns`` argument can be used to override the names of columns
         in the resulting table. The amount of columns must match the input
         data.
+
+        If the source data has a header and rows have more fields than
+        the header defines, the remaining values are put into the column
+        given by ``column_unknown``. By default it has the value "Unknown".
+
+        Examples:
+
+        .. code-block:: robotframework
+
+            # Source dialect is deduced automatically
+            ${table}=    Read table from CSV    export.csv
+            Log   Found columns: ${table.columns}
+
+            # Source dialect is known and given explicitly
+            ${table}=    Read table from CSV    export-excel.csv    dialect=excel
+            Log   Found columns: ${table.columns}
         """
         sniffer = csv.Sniffer()
-        with open(path, newline="") as fd:
+        with open(path, newline="", encoding=encoding) as fd:
             sample = fd.read(1024)
 
         if dialect is None:
@@ -1451,29 +1522,42 @@ class Tables:
 
         with open(path, newline="") as fd:
             if header:
-                reader = csv.DictReader(fd, dialect=dialect)
+                reader = csv.DictReader(
+                    fd, dialect=dialect, restkey=str(column_unknown)
+                )
             else:
                 reader = csv.reader(fd, dialect=dialect)
             rows = list(reader)
 
         table = Table(rows, columns)
         notebook_table(self.table_head(table, 10))
+
+        if header and column_unknown in table.columns:
+            self.logger.warning(
+                "CSV file (%s) had fields not defined in header, "
+                "which can be the result of a wrong dialect",
+                path,
+            )
+
         return table
 
-    def write_table_to_csv(self, table, path, header=True, dialect="excel"):
+    def write_table_to_csv(
+        self, table, path, header=True, dialect="excel", encoding=None
+    ):
         """Write a table as a CSV file.
 
-        :param path:    path to write to
-        :param table:   table to write
-        :param header:  write columns as header to CSV file
-        :param dialect: the format of output CSV
+        :param path:     path to write to
+        :param table:    table to write
+        :param header:   write columns as header to CSV file
+        :param dialect:  the format of output CSV
+        :param encoding: text encoding for output file,
+                         uses system encoding by default
 
         Valid ``dialect`` values are ``excel``, ``excel-tab``, and ``unix``.
-
         """
         self._requires_table(table)
 
-        with open(path, mode="w", newline="") as fd:
+        with open(path, mode="w", newline="", encoding=encoding) as fd:
             writer = csv.DictWriter(fd, fieldnames=table.columns, dialect=dialect)
 
             if header:
